aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorpapoteur-mga <yves.brungard_git@gadz.org>2014-10-24 20:53:01 +0200
committerpapoteur-mga <yves.brungard_git@gadz.org>2014-10-24 20:53:01 +0200
commitd99edcb65b6249a6236a802377cc06f6feb29335 (patch)
tree957542187bdecaa5b2c50c57ea541971767d6d5d
parent2ea25a0c06606419f750069359f06abf43bb7396 (diff)
downloadisodumper-d99edcb65b6249a6236a802377cc06f6feb29335.tar
isodumper-d99edcb65b6249a6236a802377cc06f6feb29335.tar.gz
isodumper-d99edcb65b6249a6236a802377cc06f6feb29335.tar.bz2
isodumper-d99edcb65b6249a6236a802377cc06f6feb29335.tar.xz
isodumper-d99edcb65b6249a6236a802377cc06f6feb29335.zip
Change the name in .img for backup
-rwxr-xr-xlib/isodumper.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/isodumper.py b/lib/isodumper.py
index 0f9ad1a..563610a 100755
--- a/lib/isodumper.py
+++ b/lib/isodumper.py
@@ -170,9 +170,9 @@ class IsoDumper:
# Unckeck the choice to backup
self.backup.set_active(0)
else:
- # Add .iso if not specified
- if not exit_dialog.lower().endswith('.iso'):
- exit_dialog=exit_dialog+".iso"
+ # Add .img if not specified
+ if not exit_dialog.lower().endswith('.img'):
+ exit_dialog=exit_dialog+".img"
self.backup_select.set_label(exit_dialog)
self.choose.hide()